==> nextcloud-13.0.1.tgz: nextcloud/apps/files_texteditor/l10n/nl.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "opslaan...",
    "saved!" : "opgeslagen!",
    "failed!" : "mislukt!",
    "Saved" : "Bewaard",
    "There was a problem saving your changes. Click to resume editing." : "Probleem bij het opslaan van je wijzigingen. Klik om door te gaan met bewerken.",
    "An error occurred!" : "Er is iets fout gegaan!",
    "Edit" : "Bewerk",
    "Mixed" : "Gemengd",
    "Preview" : "Voorbeeldweergave",
    "New text file" : "Nieuw tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt",
    "You can not open a folder" : "Je kunt geen map openen",
    "This file is too big to be opened. Please download the file instead." : "Dit bestand is te groot om te worden geopend. Download het bestand om het te bewerken.",
    "Cannot read the file." : "Kan het bestand niet lezen.",
    "Invalid file path supplied." : "Ongeldig pad opgegeven.",
    "The file is locked." : "Het bestand is besloten.",
    "An internal server error occurred." : "Er heeft zich een interne serverfout voorgedaan.",
    "You can not write to a folder" : "Je kunt schrijven naar een map",
    "Cannot save file as it has been modified since opening" : "Kan het bestand niet opslaan omdat het is gewijzigd na het openen",
    "Insufficient permissions" : "Onvoldoende rechten",
    "File path not supplied" : "Bestandspad niet opgegeven",
    "File mtime not supplied" : "Tijdstempel bestand niet opgegeven",
    "Text editor" : "Tekstverwerker"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/files_texteditor/l10n/nl.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "opslaan...",
    "saved!" : "opgeslagen!",
    "failed!" : "mislukt!",
    "Saved" : "Bewaard",
    "There was a problem saving your changes. Click to resume editing." : "Probleem bij het opslaan van je wijzigingen. Klik om door te gaan met bewerken.",
    "An error occurred!" : "Er is iets fout gegaan!",
    "Edit" : "Bewerk",
    "Mixed" : "Gemengd",
    "Preview" : "Voorbeeldweergave",
    "New text file" : "Nieuw tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt",
    "You can not open a folder" : "Je kunt geen map openen",
    "This file is too big to be opened. Please download the file instead." : "Dit bestand is te groot om te worden geopend. Download het bestand om het te bewerken.",
    "Cannot read the file." : "Kan het bestand niet lezen.",
    "Invalid file path supplied." : "Ongeldig pad opgegeven.",
    "The file is locked." : "Het bestand is besloten.",
    "An internal server error occurred." : "Er heeft zich een interne serverfout voorgedaan.",
    "You can not write to a folder" : "Je kunt schrijven naar een map",
    "Cannot save file as it has been modified since opening" : "Kan het bestand niet opslaan omdat het is gewijzigd na het openen",
    "Insufficient permissions" : "Onvoldoende rechten",
    "File path not supplied" : "Bestandspad niet opgegeven",
    "File mtime not supplied" : "Tijdstempel bestand niet opgegeven",
    "Share not found" : "Share niet gevonden",
    "You are not authorized to open this share" : "Je bent niet bevoegd deze share te openen",
    "Invalid range request" : "Ongeldige aanvraag",
    "Text editor" : "Tekstverwerker"
},
"nplurals=2; plural=(n != 1);");
